@@ -24,6 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
 #include "gdkwindow.h"
 #include "gdkinternals.h"
 #include "gdk.h"		/* For gdk_rectangle_union() */
@@ -851,41 +852,6 @@ gdk_window_begin_paint_rect (GdkWindow    *window,
   gdk_region_destroy (region);
 }
 
-static GdkGC *
-gdk_window_get_bg_gc (GdkWindow      *window,
-		      GdkWindowPaint *paint)
-{
-  GdkWindowObject *private = (GdkWindowObject *)window;
-
-  guint gc_mask = 0;
-  GdkGCValues gc_values;
-
-  if (private->bg_pixmap == GDK_PARENT_RELATIVE_BG && private->parent)
-    {
-      GdkWindowPaint tmp_paint = *paint;
-      tmp_paint.x_offset += private->x;
-      tmp_paint.y_offset += private->y;
-      
-      return gdk_window_get_bg_gc (GDK_WINDOW (private->parent), &tmp_paint);
-    }
-  else if (private->bg_pixmap && 
-           private->bg_pixmap != GDK_PARENT_RELATIVE_BG && 
-           private->bg_pixmap != GDK_NO_BG)
-    {
-      gc_values.fill = GDK_TILED;
-      gc_values.tile = private->bg_pixmap;
-      
-      gc_mask = GDK_GC_FILL | GDK_GC_TILE;
-    }
-  else
-    {
-      gc_values.foreground = private->bg_color;
-      gc_mask = GDK_GC_FOREGROUND;
-    }
-
-  return gdk_gc_new_with_values (paint->pixmap, &gc_values, gc_mask);
-}
-
 #ifdef GDK_WINDOWING_X11
 #include "x11/gdkx.h"
 #endif
@@ -1020,7 +986,7 @@ gdk_window_end_paint (GdkWindow *window)
 
   gdk_region_get_clipbox (paint->region, &clip_box);
 
-  tmp_gc = gdk_gc_new (window);
+  tmp_gc = _gdk_drawable_get_scratch_gc (window, FALSE);
 
   _gdk_windowing_window_get_offsets (window, &x_offset, &y_offset);
 
@@ -1033,7 +999,9 @@ gdk_window_end_paint (GdkWindow *window)
                      clip_box.x - x_offset, clip_box.y - y_offset,
                      clip_box.width, clip_box.height);
 
-  g_object_unref (tmp_gc);
+  /* Reset clip region of the cached GdkGC */
+  gdk_gc_set_clip_region (tmp_gc, NULL);
+  
   g_object_unref (paint->pixmap);
   gdk_region_destroy (paint->region);
   g_free (paint);
@@ -1398,7 +1366,7 @@ gdk_window_get_composite_drawable (GdkDrawable *drawable,
     return g_object_ref (drawable);
 
   tmp_pixmap = gdk_pixmap_new (drawable, width, height, -1);
-  tmp_gc = gdk_gc_new (tmp_pixmap);
+  tmp_gc = _gdk_drawable_get_scratch_gc (tmp_pixmap, FALSE);
 
   /* Copy the current window contents */
   gdk_draw_drawable (tmp_pixmap,
@@ -1423,12 +1391,13 @@ gdk_window_get_composite_drawable (GdkDrawable *drawable,
 			 0, 0, width, height);
     }
 
+  /* Reset clip region of the cached GdkGC */
+  gdk_gc_set_clip_region (tmp_gc, NULL);
+
   /* Set these to location of tmp_pixmap within the window */
   *composite_x_offset = x;
   *composite_y_offset = y;
 
-  g_object_unref (tmp_gc);
-  
   return tmp_pixmap;
 }
 
@@ -1660,6 +1629,44 @@ gdk_window_draw_glyphs (GdkDrawable      *drawable,
   RESTORE_GC (gc);
 }
 
+static GdkGC *
+gdk_window_get_bg_gc (GdkWindow      *window,
+		      GdkWindowPaint *paint)
+{
+  GdkWindowObject *private = (GdkWindowObject *)window;
+
+  guint gc_mask = 0;
+  GdkGCValues gc_values;
+
+  if (private->bg_pixmap == GDK_PARENT_RELATIVE_BG && private->parent)
+    {
+      GdkWindowPaint tmp_paint = *paint;
+      tmp_paint.x_offset += private->x;
+      tmp_paint.y_offset += private->y;
+      
+      return gdk_window_get_bg_gc (GDK_WINDOW (private->parent), &tmp_paint);
+    }
+  else if (private->bg_pixmap && 
+           private->bg_pixmap != GDK_PARENT_RELATIVE_BG && 
+           private->bg_pixmap != GDK_NO_BG)
+    {
+      gc_values.fill = GDK_TILED;
+      gc_values.tile = private->bg_pixmap;
+      
+      gc_mask = GDK_GC_FILL | GDK_GC_TILE;
+
+      return gdk_gc_new_with_values (paint->pixmap, &gc_values, gc_mask);
+    }
+  else
+    {
+      GdkGC *gc = _gdk_drawable_get_scratch_gc (paint->pixmap, FALSE);
+
+      gdk_gc_set_foreground (gc, &(private->bg_color));
+
+      return g_object_ref (gc);
+    }
+}
+
 static void
 gdk_window_clear_backing_rect (GdkWindow *window,
 			       gint       x,
@@ -1680,6 +1687,8 @@ gdk_window_clear_backing_rect (GdkWindow *window,
   gdk_draw_rectangle (window, tmp_gc, TRUE,
 		      x, y, width, height);
 
+  gdk_gc_set_clip_region (tmp_gc, NULL);
+  
   g_object_unref (tmp_gc);
 }
 
@@ -1941,12 +1950,12 @@ gdk_window_copy_to_image (GdkDrawable     *drawable,
   
   _gdk_windowing_window_get_offsets (drawable, &x_offset, &y_offset);
   
-  return _gdk_drawable_copy_to_image (((GdkWindowObject*)drawable)->impl,
-				      image,
-				      src_x - x_offset,
-				      src_y - y_offset,
-				      dest_x, dest_y,
-				      width, height);
+  return gdk_drawable_copy_to_image (((GdkWindowObject*)drawable)->impl,
+				     image,
+				     src_x - x_offset,
+				     src_y - y_offset,
+				     dest_x, dest_y,
+				     width, height);
 }
 
 /* Code for dirty-region queueing
