@@ -18,6 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+
 #include "gtkfilesystem.h"
 #include "gtkfilesystemunix.h"
 #include "gtkicontheme.h"
@@ -376,13 +378,14 @@ gtk_file_system_unix_create_folder (GtkFileSystem     *file_system,
 
   if (!result)
     {
+      int save_errno = errno;
       gchar *filename_utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
       g_set_error (error,
 		   GTK_FILE_SYSTEM_ERROR,
 		   GTK_FILE_SYSTEM_ERROR_NONEXISTENT,
 		   _("error creating directory '%s': %s"),
 		   filename_utf8 ? filename_utf8 : "???",
-		   g_strerror (errno));
+		   g_strerror (save_errno));
       g_free (filename_utf8);
       return FALSE;
     }
@@ -461,19 +464,22 @@ get_icon_type (const char *filename,
 
   /* If stat fails, try to fall back to lstat to catch broken links
    */
-  if (stat (filename, &statbuf) != 0 &&
-      lstat (filename, &statbuf) != 0)
+  if (stat (filename, &statbuf) != 0)
     {
-      gchar *filename_utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
-      g_set_error (error,
-		   GTK_FILE_SYSTEM_ERROR,
-		   GTK_FILE_SYSTEM_ERROR_NONEXISTENT,
-		   _("error getting information for '%s': %s"),
-		   filename_utf8 ? filename_utf8 : "???",
-		   g_strerror (errno));
-      g_free (filename_utf8);
+      if (errno != ENOENT || lstat (filename, &statbuf) != 0)
+	{
+	  int save_errno = errno;
+	  gchar *filename_utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
+	  g_set_error (error,
+		       GTK_FILE_SYSTEM_ERROR,
+		       GTK_FILE_SYSTEM_ERROR_NONEXISTENT,
+		       _("error getting information for '%s': %s"),
+		       filename_utf8 ? filename_utf8 : "???",
+		       g_strerror (save_errno));
+	  g_free (filename_utf8);
 
-      return ICON_NONE;
+	  return ICON_NONE;
+	}
     }
 
   if (S_ISBLK (statbuf.st_mode))
@@ -822,6 +828,25 @@ gtk_file_system_unix_filename_to_path (GtkFileSystem *file_system,
   return gtk_file_path_new_dup (filename);
 }
 
+static const char *
+get_icon_for_directory (const char *path)
+{
+  static char *desktop_path = NULL;
+
+  if (!g_get_home_dir ())
+    return "gnome-fs-directory";
+
+  if (!desktop_path)
+      desktop_path = g_build_filename (g_get_home_dir (), "Desktop", NULL);
+
+  if (strcmp (g_get_home_dir (), path) == 0)
+    return "gnome-fs-home";
+  else if (strcmp (desktop_path, path) == 0)
+    return "gnome-fs-desktop";
+  else
+    return "gnome-fs-directory";
+}
+
 static GdkPixbuf *
 gtk_file_system_unix_render_icon (GtkFileSystem     *file_system,
 				  const GtkFilePath *path,
@@ -860,7 +885,7 @@ gtk_file_system_unix_render_icon (GtkFileSystem     *file_system,
 	  name = "gnome-fs-chardev";
 	  break;
 	case ICON_DIRECTORY:
-	  name = "gnome-fs-directory";
+	  name = get_icon_for_directory (filename);
 	  break;
 	case ICON_EXECUTABLE:
 	  name ="gnome-fs-executable";
@@ -1086,7 +1111,6 @@ gtk_file_system_unix_insert_bookmark (GtkFileSystem     *file_system,
   if (!bookmark_list_read (&bookmarks, &err) && err->code != G_FILE_ERROR_NOENT)
     {
       g_propagate_error (error, err);
-      g_error_free (err);
       return FALSE;
     }
 
@@ -1365,20 +1389,22 @@ filename_get_info (const gchar     *filename,
 
   /* If stat fails, try to fall back to lstat to catch broken links
    */
-  if (do_stat &&
-      stat (filename, &statbuf) != 0 &&
-      lstat (filename, &statbuf) != 0)
+  if (do_stat && stat (filename, &statbuf) != 0)
     {
-      gchar *filename_utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
-      g_set_error (error,
-		   GTK_FILE_SYSTEM_ERROR,
-		   GTK_FILE_SYSTEM_ERROR_NONEXISTENT,
-		   _("error getting information for '%s': %s"),
-		   filename_utf8 ? filename_utf8 : "???",
-		   g_strerror (errno));
-      g_free (filename_utf8);
+      if (errno != ENOENT || lstat (filename, &statbuf) != 0)
+	{
+	  int save_errno = errno;
+	  gchar *filename_utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
+	  g_set_error (error,
+		       GTK_FILE_SYSTEM_ERROR,
+		       GTK_FILE_SYSTEM_ERROR_NONEXISTENT,
+		       _("error getting information for '%s': %s"),
+		       filename_utf8 ? filename_utf8 : "???",
+		       g_strerror (save_errno));
+	  g_free (filename_utf8);
 
-      return NULL;
+	  return NULL;
+	}
     }
 
   info = gtk_file_info_new ();
