@@ -24,6 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <string.h>
@@ -997,7 +998,7 @@ icon_size_settings_changed (GtkSettings  *settings,
 {
   icon_size_set_all_from_settings (settings);
 
-  _gtk_rc_reset_styles (settings);
+  gtk_rc_reset_styles (settings);
 }
 
 static void
@@ -2702,7 +2703,10 @@ copy_cache (GtkIconSet *icon_set,
       *icon_copy = *icon;
 
       if (icon_copy->style)
-        attach_to_style (copy_recipient, icon_copy->style);
+	{
+	  attach_to_style (copy_recipient, icon_copy->style);
+	  g_object_ref (icon_copy->style);
+	}
         
       g_object_ref (icon_copy->pixbuf);
 
