@@ -34,11 +34,11 @@ extern "C" {
 
 
 #define GTK_TYPE_SOCKET            (gtk_socket_get_type ())
-#define GTK_SOCKET(obj)            (GTK_CHECK_CAST ((obj), GTK_TYPE_SOCKET, GtkSocket))
-#define GTK_SOCKET_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_SOCKET, GtkSocketClass))
-#define GTK_IS_SOCKET(obj)         (GTK_CHECK_TYPE ((obj), GTK_TYPE_SOCKET))
-#define GTK_IS_SOCKET_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SOCKET))
-#define GTK_SOCKET_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_SOCKET, GtkSocketClass))
+#define GTK_SOCKET(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_SOCKET, GtkSocket))
+#define GTK_SOCKET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_SOCKET, GtkSocketClass))
+#define GTK_IS_SOCKET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_SOCKET))
+#define GTK_IS_SOCKET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SOCKET))
+#define GTK_SOCKET_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_SOCKET, GtkSocketClass))
 
 
 typedef struct _GtkSocket        GtkSocket;
@@ -62,7 +62,8 @@ struct _GtkSocket
   guint have_size : 1;
   guint need_map : 1;
   guint is_mapped : 1;
-
+  guint active : 1;
+  
   GtkAccelGroup *accel_group;
   GtkWidget *toplevel;
 };
@@ -71,8 +72,8 @@ struct _GtkSocketClass
 {
   GtkContainerClass parent_class;
 
-  void     (*plug_added)   (GtkSocket *socket);
-  gboolean (*plug_removed) (GtkSocket *socket);
+  void     (*plug_added)   (GtkSocket *socket_);
+  gboolean (*plug_removed) (GtkSocket *socket_);
 
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
@@ -82,15 +83,15 @@ struct _GtkSocketClass
 };
 
 
+GType          gtk_socket_get_type (void) G_GNUC_CONST;
 GtkWidget*     gtk_socket_new      (void);
-GtkType        gtk_socket_get_type (void) G_GNUC_CONST;
 
-void            gtk_socket_add_id (GtkSocket       *socket,
+void            gtk_socket_add_id (GtkSocket       *socket_,
 				   GdkNativeWindow  window_id);
-GdkNativeWindow gtk_socket_get_id (GtkSocket       *socket);
+GdkNativeWindow gtk_socket_get_id (GtkSocket       *socket_);
 
 #ifndef GTK_DISABLE_DEPRECATED
-void           gtk_socket_steal    (GtkSocket      *socket,
+void           gtk_socket_steal    (GtkSocket      *socket_,
 				    GdkNativeWindow wid);
 #endif /* GTK_DISABLE_DEPRECATED */
 
